/* 
   
   Geeks Artificial Neural Network (G.A.N.N) - Save Data To GKDB
   
   Copyright GNU/GPL 2005-2006 George Delaportas (qtgeo)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

*/



//Geeks Save Data (Function)
void GSaveData(GNeuron *GMatrix)

{

    //Variables
    int i,j;
    FILE *FileToSave;
    
    //Initialize GKDB
    FileToSave=fopen("GKDB","a");
    
    //Set Starting Header
    fprintf(FileToSave,"%i\n%i\n%i\n%i\n%f\n%i\n%i\n%i\n%i\n",\
    SimNum,ECT,GMSType,GMCType,Threshold,GNNum,Layers,Inputs,Outputs);
    
    for (i=0;i<GNNum;i++)
    
    {
    
        fprintf(FileToSave,"%i\n",i+1);
        fprintf(FileToSave,"%i\n",GMatrix[i].GetInData(i));
        fprintf(FileToSave,"%i\n",GMatrix[i].GetWeights(i));
        fprintf(FileToSave,"%i\n",GMatrix[i].GetNFT());
        fprintf(FileToSave,"%f\n",GMatrix[i].GetBase());
        fprintf(FileToSave,"%f\n",GMatrix[i].GetSum());
        fprintf(FileToSave,"%f\n",GMatrix[i].OutData());
    
    }
    
    //Close GKDB
    fclose(FileToSave);

}

/* ------------------------------------------------------------------------ */
